package cd.casic.ci.process.engine.worker;

import cd.casic.ci.process.common.WorkAtom;
import cd.casic.ci.process.dal.resp.resource.ResourceFindResp;
import cd.casic.ci.process.engine.constant.AFLConstant;
import cd.casic.ci.process.engine.constant.DIYImageExecuteCommandConstant;
import cd.casic.ci.process.engine.runContext.TaskRunContext;
import cd.casic.ci.process.engine.worker.base.DockerWorker;
import cd.casic.ci.process.engine.worker.base.SshWorker;
import cd.casic.ci.process.process.dataObject.machine.MachineInfo;
import cd.casic.ci.process.process.dataObject.pipeline.PipPipeline;
import cd.casic.ci.process.process.dataObject.task.PipTask;
import cd.casic.module.execute.docker.dataobject.dto.DockerEndpointDo;
import cd.casic.module.execute.docker.dataobject.model.DockerEndpoint;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import java.util.Map;

@WorkAtom(taskType = "AFL")
@Slf4j
public class AFLWorker extends DockerWorker {


    @Override
    public void execute(TaskRunContext context) {
        int statusCode = -1;
        Map<String, Object> localVariables = context.getLocalVariables();
        if (context.getContextDef() instanceof PipTask taskDef) {
            log.info(taskDef.getTaskName());
            Map<String, Object> taskProperties = taskDef.getTaskProperties();
            Object commandScriptObj = taskProperties.get(AFLConstant.COMMAND_SCRIPT);
//            Object machineIdObj = taskProperties.get(DIYImageExecuteCommandConstant.MACHINE_ID);
            String commandScript = commandScriptObj instanceof String ? ((String) commandScriptObj) : null;

            PipPipeline pipeline = (PipPipeline) getContextManager().getContext(taskDef.getPipelineId()).getContextDef();
            String resourceId = pipeline.getResourceId();
            if (StringUtils.isEmpty(commandScript)||StringUtils.isEmpty(resourceId)) {
//                缺少参数
                toBadEnding();
            }
            ResourceFindResp resourceById = getResourceManagerService().findResourceById(resourceId);
            DockerEndpointDo dockerEndpoint = resourceById.getDockerEndpoint();
            if (dockerEndpoint==null) {
                append(context,"当前机器不支持docker");
                return;
            }
            try {
                //将节点的配置信息反编译成对象
                log.info("构建脚本" + commandScript);

                //如果machineId为0，则说明该节点没有配置机器，则使用开始节点的机器

                //获取机器
//                MachineInfo machineInfoDO = this.getMachineInfoService().getById(machineId);
                // 获取docker 暂时先写固定值
                // TODO dockerEndpoint替换为查询
                dockerRun(commandScript,dockerEndpoint,context);
            } catch (Exception e) {
                String errorMessage = "该节点配置信息为空，请先配置该节点信息" + "\r\n";
                log.error("执行ssh失败:", e);
                append(context, errorMessage);
                toBadEnding();
            }
            localVariables.put(DIYImageExecuteCommandConstant.STATUS_CODE, statusCode);
        }
    }
}
